@@ -160,7 +160,12 @@ class _Resource(object):
         except ValueError:
             return self.attributes[item]
         except KeyError:
-            return self.action_if_attribute_absent()
+            if self.is_new():
+                if item in ('id', 'version'):
+                    return 0
+                return ''
+
+            return self._action_if_attribute_absent()
 
     def __setattr__(self, item, value):
         """Sets the requested attribute"""
@@ -183,6 +188,7 @@ class _Resource(object):
             self.attributes['custom_fields'].extend(value)
             self._changes[item] = self.attributes['custom_fields']
         else:
+            value = self.manager.prepare_params({item: value})[item]
             self._changes[item] = value
             self.attributes[item] = value
 
@@ -213,7 +219,7 @@ class _Resource(object):
 
     def save(self):
         """Creates or updates a resource"""
-        if 'id' in self.attributes or 'created_on' in self.attributes:
+        if not self.is_new():
             self.pre_update()
             self.manager.update(self.internal_id, **self._changes)
             self.attributes['updated_on'] = datetime.utcnow().strftime(self.manager.redmine.datetime_format)
@@ -242,7 +248,11 @@ class _Resource(object):
         """Returns identifier of the resource for usage in internals of the library"""
         return self.id
 
-    def action_if_attribute_absent(self):
+    def is_new(self):
+        """Checks if resource was just created and not yet saved to Redmine or it is existent resource"""
+        return False if 'id' in self.attributes or 'created_on' in self.attributes else True
+
+    def _action_if_attribute_absent(self):
         """Whether we should raise an exception in case of attribute absence or just return None"""
         raise_attr_exception = self.manager.redmine.raise_attr_exception
 
@@ -467,6 +477,17 @@ class WikiPage(_Resource):
     def internal_id(self):
         return self.title
 
+    def __getattr__(self, item):
+        # If a text attribute of a resource is missing, we should
+        # refresh a resource automatically for user's convenience
+        try:
+            return super(WikiPage, self).__getattr__(item)
+        except ResourceAttrError:
+            if 'text' not in self.attributes:
+                self.attributes = self.refresh().attributes
+
+            return super(WikiPage, self).__getattr__(item)
+
     def __int__(self):
         return self.version
 
